{% extends "exoral/base.html" %}

{% block content %}
<div class="container">
  <nav aria-label="breadcrumb">
    <ol class="breadcrumb">
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:home' %}">Start</a></li>
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:fach-list' %}">Fächer</a></li>
      <li class="breadcrumb-item active" aria-current="page">{{ fach }}</li>
    </ol>
  </nav>

  {% include "exoral/fach_form.html" %}

  <div class="row">
    <div class="col">
      <div class="alert alert-danger">
        Wenn du das gesamte Fach löschen willst, dann erledige das <a class="alert-link" target="_blank" href="{% url 'admin:exoral_fach_change' fach.id %}">über die Admin-Oberfläche</a>.
        {% if not user.is_staff %}
        Dafür musst du von einem Administrator den <em>Mitarbeiter-Status</em> erhalten. Wende dich an die Admins, damit sie dir das Häkchen setzen.
        {% endif %}
        Bedenke, dass beim Löschen eines Fachs auch alle dazugehörigen Dozenten und Fragen gelöscht werden. In der Admin-Oberfläche siehst du genau, was dazu gelöscht wird.
      </div>
    </div>
  </div>
</div>
{% endblock content %}
