{% extends "exoral/base.html" %}

{% block content %}
<div class="container">
  <nav aria-label="breadcrumb">
    <ol class="breadcrumb">
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:home' %}">Start</a></li>
      <li class="breadcrumb-item active" aria-current="page">Dozenten</li>
      {% if perms.exoral.add_dozent %}
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:dozent-create' %}">hinzufügen</a></li>
      {% endif %}
    </ol>
  </nav>

  <table class="table table-striped">
    <thead>
      <tr>
        <th>Titel</th>
        <th>Name</th>
        <th>Fach</th>
      </tr>
    </thead>
    <tbody>
      {% for dozent in dozent_list %}
      <tr>
        <td>{{ dozent.titel }}</td>
        <td><a href="{% url 'exoral:dozent-detail' dozent.id %}">{{ dozent.vorname }} {{ dozent.nachname }}</a></td>
        <td>{{ dozent.fach }}</td>
      </tr>
      {% endfor %}
    </tbody>
  </table>
</div>
{% endblock content %}
