{% extends "exoral/base.html" %}

{% block content %}
<div class="container">
  <nav aria-label="breadcrumb">
    <ol class="breadcrumb">
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:home' %}">Start</a></li>
      <li class="breadcrumb-item" aria-current="page"><a href="{% url 'exoral:fach-list' %}">Fächer</a></li>
      <li class="breadcrumb-item active" aria-current="page">hinzufügen</li>
    </ol>
  </nav>

  {% include "exoral/fach_form.html" %}
</div>
{% endblock content %}
