{% extends "exoral/base.html" %}

{% block content %}
<div class="container">
  <div class="row">
    <div class="col">
      {% if testate %}
      <p>
        Hallo {{ name }},<br>
        hier sind die für dich interessanten Testate für {{ studiengang }} im {{ studienabschnitt }}:
      </p>
      <ul>
        {% for testat in testate %}
        <li><a href="{% url 'exoral:testat-detail' testat.pk %}">{{ testat }}</a></li>
        {% endfor %}
      </ul>
      <p>
        Deine Einstellungen kannst du <a href="{% url 'fsmedhro_core:edit' %}" target="_blank">in deinem Profil</a> ändern.
      </p>
      {% else %}
      <p>Keine Testate gefunden. Bitte wende dich an den FSR, damit Testate erstellt werden.</p>
      {% endif %}
    </div>
  </div>
  <div class="row">
    <div class="col">
      <h6>Übersichten</h6>
    </div>
  </div>
  <div class="row">
    <div class="col">
      <ul>
        <li><a href="{% url 'exoral:dozent-list' %}" target="_blank">Dozenten</a></li>
        <li><a href="{% url 'exoral:fach-list' %}" target="_blank">Fächer</a></li>
        <li><a href="{% url 'exoral:testat-list' %}" target="_blank">Testate</a></li>
      </ul>
    </div>
  </div>
  <div class="row">
    <div class="col">
      <h6>Die letzten 20 Fragen:</h6>
      <table class="table table-striped">
        <thead>
          <tr>
            <th>Frage</th>
            <th>Prüfer:in</th>
            <th>Testat</th>
            <th style="width: 20ex;">Datum</th>
          </tr>
        </thead>
        <tbody>
          {% for frage in letzte_fragen %}
          <tr>
            <td>
              {% if perms.exoral.change_frage %}
              <a href="{% url 'exoral:frage-edit' frage.id %}" target="_blank">{{ frage }}</a>
              {% else %}
              <a href="{% url 'exoral:frage-list' frage.testat.id frage.pruefer.id %}" target="_blank">{{ frage }}</a>
              {% endif %}
            </td>
            <td>
              <a href="{% url 'exoral:dozent-detail' frage.pruefer.id %}" target="_blank">{{ frage.pruefer }}</a>
            </td>
            <td>
              <a href="{% url 'exoral:testat-detail' frage.testat.id %}" target="_blank">{{ frage.testat }}</a>
            </td>
            <td>{{ frage.datum }}</td>
          </tr>
          {% endfor %}
        </tbody>
      </table>
    </div>
  </div>
</div>
{% endblock content %}
