# Generated by Django 3.0.10 on 2020-11-13 19:52

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('exoral', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='frage',
            name='abgestimmte_benutzer',
            field=models.ManyToManyField(blank=True, to=settings.AUTH_USER_MODEL),
        ),
    ]
